/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Automation, New Tasks, and Inequality, By Daron Acemoglu and Pascual Restrepo
Created 11/30/2019
Pascual Restrepo
* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

if missing("`project'") {
	global project ~/Dropbox/RA_Pascual/Replication/Acemoglu_Restrepo_SBTC_PP
}

***Parameters used in JEP paper***
global growth_rate_1987_2017 0.0146
global growth_rate_1947_1987 0.02


forvalues sigma = 0.8(0.2)1.0 {

* locals to store results *
local sigma1 = `sigma' - mod(`sigma',1)
local sigma2 = mod(`sigma'*10,10)

***Task content measures using BEA for 1947-1987***
use ${project}/raw_data/panel_bea72.dta, clear
joinby industry_consolidated using  ${project}/xwalks/industry_xwalk_nipa_bea.dta

**Aggregate data to consolidated insutries**
preserve
collapse (sum) bea72_vadded bea72_comp [iw=afac], by(consolidated_bea year)
tempfile aggregates
save `aggregates'
restore

preserve
gen capinc=max(bea72_vadded-bea72_comp,0.1)
collapse (mean) bea72_R_full [w=capinc*afac], by(consolidated_bea year)
tempfile R
save `R'
restore

preserve
collapse (mean) bea72_W_unadj [w=bea72_comp*afac], by(consolidated_bea year)
tempfile W
save `W'
restore

*************************************************
*****Measure according to BEA data 1947-1987*****
*************************************************
use `aggregates', clear
merge 1:1 consolidated_bea year using `R', assert(3) nogenerate
merge 1:1 consolidated_bea year using `W', assert(3) nogenerate
encode consolidated_bea, gen(indcode)
sort indcode year
gen vadded_i=bea72_vadded
gen wages_i=bea72_comp
gen priceR_i=bea72_R_full
gen priceW_i=bea72_W_unadj

* * * Sectoral shares and statistics                                    * * * * 
* * * Share of GDP, Labor share at time t and at intitial point (1987)  * * * *

bys year: egen wbill_us=total(wages_i)					/*Wage bill in nominal terms*/

* * * Measure the contribution of changes in TASK CONTENT of production  		* * * *
* * *  and SUBSTITUTION effects (see the appendix for derivations, pagg. A8-A10) * * * *
sort indcode year

gen labsh_i=wages_i/vadded_i 				/*Labor share i: Contribution of labor to value added in sector i (s_i)*/

bys indcode: gen base_labsh=labsh_i[1]		/*Initial labor share in industry i (s_i in 1987) */
assert base_labsh==labsh_i if year==1947

gen logW_i=ln(priceW_i)		/*Observed wages adjusted from composition, BLS (ln_W_i)*/ 

gen logR_i=ln(priceR_i)		/*Observed rental rates of capital, BLS (ln_R_i)*/

gen ln_labsh_i=ln(labsh_i)  /*Observed decline in labor share, BEA */

gen substitution_i=(1-${sigma})*(1-base_labsh)*(d.logW_i-d.logR_i-${growth_rate_1947_1987}) /*Formula for the substitution effect (see appendix - pag. A9)*/

gen task_content_i=d.ln_labsh_i-substitution_i                                             	/*Formula for changes in the task content (see appendix - pag. A9)*/

* * * Disentangle the DISPLACEMENT and REINSTATEMENT effect using 5 year moving averages * * *
sort indcode year

* Calculate mean of task content for each industry at 5 years MA centered at current year
* (Baseline: 5-year moving averages) 
rangestat (mean) task_content_*, interval(year -2 2) by(indcode)

*Industry element of the Displacement effect:
gen task_negative_5yr=min(task_content_i_mean,0) 

*Industry element of the Reinstatement effect: 
gen task_positive_5yr=max(task_content_i_mean,0)

* Calculate mean of task content for each industry at 11 years MA centered at current year
* (Baseline: 5-year moving averages) 
drop task_content_i_mean
rangestat (mean) task_content_*, interval(year -5 5) by(indcode)

*Industry element of the Displacement effect:
gen task_negative_10yr=min(task_content_i_mean,0) 

*Industry element of the Reinstatement effect: 
gen task_positive_10yr=max(task_content_i_mean,0) 
 
gen indwts=wages_i/wbill_us /*Use share of wage bill as weights for industry analysis (l_i)*/
collapse (sum) task_negative_*yr task_positive_*yr task_content_i (mean) indwts, by(consolidated_bea)
save ${project}/clean_data/task_content_bea_1947_1987_`sigma1'.`sigma2'.dta, replace


***Prepare xwalk from ind1990 to consolidated BEA***
use ${project}/xwalks/industry_xwalk_census_bea.dta, clear
keep if industry_bea!=""
replace industry_bea=ltrim(rtrim(industry_bea))
keep consolidated_bea industry_bea
tempfile xw_bea
save `xw_bea'

***Task content measures using BEA for 1987-2017***
use ${project}/raw_data/panel_beaNAICS.dta, clear
replace industry_bea=ltrim(rtrim(industry_bea))
merge m:1 industry_bea using `xw_bea', assert(3)

**Aggregate data to consolidated insutries**
preserve
collapse (sum) bea_vadded bea_comp bls_L_inc bls_K_inc, by(consolidated_bea year)
tempfile aggregates
save `aggregates'
restore

preserve
collapse (mean) bls_R_full [w=max(bls_K_inc,0)], by(consolidated_bea year)
tempfile R
save `R'
restore

preserve
collapse (mean) bls_W_adj [w=bls_L_inc], by(consolidated_bea year)
tempfile W
save `W'
restore

*************************************************
*****Measure according to BEA data 1987-2017*****
*************************************************
use `aggregates', clear
merge 1:1 consolidated_bea year using `R', assert(3) nogenerate
merge 1:1 consolidated_bea year using `W', assert(3) nogenerate
encode consolidated_bea, gen(indcode)

sort indcode year
gen vadded_i=bea_vadded
gen wages_i=bea_comp
gen priceR_i=bls_R_full
gen priceW_i=bls_W_adj

* * * Sectoral shares and statistics                                    * * * * 
* * * Share of GDP, Labor share at time t and at intitial point (1987)  * * * *

bys year: egen wbill_us=total(wages_i)					/*Wage bill in nominal terms*/

* * * Measure the contribution of changes in TASK CONTENT of production  		* * * *
* * *  and SUBSTITUTION effects (see the appendix for derivations, pagg. A8-A10) * * * *
sort indcode year

gen labsh_i=wages_i/vadded_i 				/*Labor share i: Contribution of labor to value added in sector i (s_i)*/

bys indcode: gen base_labsh=labsh_i[1]		/*Initial labor share in industry i (s_i in 1987) */
assert base_labsh==labsh_i if year==1987

gen logW_i=ln(priceW_i)		/*Observed wages adjusted from composition, BLS (ln_W_i)*/ 

gen logR_i=ln(priceR_i)		/*Observed rental rates of capital, BLS (ln_R_i)*/

gen ln_labsh_i=ln(labsh_i)  /*Observed decline in labor share, BEA */

gen substitution_i=(1-${sigma})*(1-base_labsh)*(d.logW_i-d.logR_i-${growth_rate_1987_2017}) /*Formula for the substitution effect (see appendix - pag. A9)*/

gen task_content_i=d.ln_labsh_i-substitution_i                                             	/*Formula for changes in the task content (see appendix - pag. A9)*/

* * * Disentangle the DISPLACEMENT and REINSTATEMENT effect using 5 year moving averages * * *
sort indcode year

* Calculate mean of task content for each industry at 5 years MA centered at current year
* (Baseline: 5-year moving averages) 
rangestat (mean) task_content_*, interval(year -2 2) by(indcode)

*Industry element of the Displacement effect:
gen task_negative_1yr=min(task_content_i,0) 

*Industry element of the Reinstatement effect: 
gen task_positive_1yr=max(task_content_i,0)

*Industry element of the Displacement effect:
gen task_negative_5yr=min(task_content_i_mean,0) 

*Industry element of the Reinstatement effect: 
gen task_positive_5yr=max(task_content_i_mean,0)

* Calculate mean of task content for each industry at 11 years MA centered at current year
* (Baseline: 5-year moving averages) 
drop task_content_i_mean
rangestat (mean) task_content_*, interval(year -5 5) by(indcode)

*Industry element of the Displacement effect:
gen task_negative_10yr=min(task_content_i_mean,0) 

*Industry element of the Reinstatement effect: 
gen task_positive_10yr=max(task_content_i_mean,0) 
 
gen indwts=wages_i/wbill_us /*Use share of wage bill as weights for industry analysis (l_i)*/
gcollapse (sum) task_negative_*yr task_positive_*yr task_content_i (mean) indwts, by(consolidated_bea)


save "${project}/clean_data/task_content_bea_1987_2017_`sigma1'.`sigma2'.dta", replace

}
